@@ -6,13 +6,13 @@ from kabaret.flow_contextual_dict import ContextualView, get_contextual_dict
 
 from .departments import Department
 from .maputils import ItemMap, CreateItemAction, ClearMapAction
-from .lib import AssetDependency, DropAssetAction#, KitsuSettingsView
+from .lib import AssetDependency, DropAssetAction  # , KitsuSettingsView
 from .kitsu import KitsuSequence, KitsuShot, UpdateItemsKitsuSettings
 
 
 class Casting(flow.Map):
 
-    ICON = ('icons.flow', 'casting')
+    ICON = ("icons.flow", "casting")
 
     drag_assets = flow.Child(DropAssetAction)
 
@@ -42,7 +42,7 @@ class DisplayKitsuSettings(flow.Action):
         return False
 
     def allow_context(self, context):
-        return context and context.endswith('.inline')
+        return context and context.endswith(".inline")
 
     def run(self, button):
         displayed = self._map._display_kitsu_settings.get()
@@ -59,39 +59,36 @@ class ShotDepartments(flow.Object):
 
 class Shot(KitsuShot):
 
-    ICON = ('icons.flow', 'shot')
+    ICON = ("icons.flow", "shot")
 
     _sequence = flow.Parent(2)
 
     settings = flow.Child(ContextualView).ui(hidden=True)
     # casting = flow.Child(Casting)
 
-    description = flow.Param('')
+    description = flow.Param("")
     departments = flow.Child(ShotDepartments).ui(expanded=True)
 
     def get_default_contextual_edits(self, context_name):
-        if context_name == 'settings':
+        if context_name == "settings":
             default_settings = get_contextual_dict(self._sequence, context_name)
-            path = default_settings.get('path', 'UNKNOWN_PATH')
+            path = default_settings.get("path", "UNKNOWN_PATH")
 
-            return dict(
-                path=os.path.join(path, self.name()),
-                shot=self.name()
-            )
+            return dict(path=os.path.join(path, self.name()), shot=self.name())
 
 
 class Shots(ItemMap):
 
-    ICON = ('icons.flow', 'shot')
+    ICON = ("icons.flow", "shot")
 
-    item_prefix = 'p'
+    item_prefix = "p"
 
     _display_kitsu_settings = flow.BoolParam(False)
 
-    with flow.group('Modify'):
+    with flow.group("Modify"):
         # create_shot = flow.Child(CreateItemAction)
         clear_shots = flow.Child(ClearMapAction)
-    with flow.group('Kitsu'):
+    with flow.group("Kitsu"):
         toggle_kitsu_settings = flow.Child(DisplayKitsuSettings)
         update_kitsu_settings = flow.Child(UpdateItemsKitsuSettings)
 
@@ -100,56 +97,48 @@ class Shots(ItemMap):
         return flow.injection.injectable(Shot)
 
     def columns(self):
-        names = ['Name']
+        names = ["Name"]
 
         if self._display_kitsu_settings.get():
-            names.extend([
-                'Movement',
-                'Nb frames',
-                'Frame in',
-                'Frame out',
-                'Multiplan'
-            ])
+            names.extend(
+                ["Movement", "Nb frames", "Frame in", "Frame out", "Multiplan"]
+            )
 
         return names
 
     def _fill_row_cells(self, row, item):
-        row['Name'] = item.name()
+        row["Name"] = item.name()
 
         if self._display_kitsu_settings.get():
-            row['Nb frames'] = item.kitsu_settings['nb_frames'].get()
+            row["Nb frames"] = item.kitsu_settings["nb_frames"].get()
 
-            data = item.kitsu_settings['data'].get()
+            data = item.kitsu_settings["data"].get()
 
-            row['Movement'] = data['movement']
-            row['Frame in'] = data['frame_in']
-            row['Frame out'] = data['frame_out']
-            row['Multiplan'] = data['multiplan']
+            row["Movement"] = data["movement"]
+            row["Frame in"] = data["frame_in"]
+            row["Frame out"] = data["frame_out"]
+            row["Multiplan"] = data["multiplan"]
 
 
 class Sequence(KitsuSequence):
 
-    ICON = ('icons.flow', 'sequence')
+    ICON = ("icons.flow", "sequence")
 
     _map = flow.Parent()
 
     settings = flow.Child(ContextualView).ui(hidden=True)
-    description = flow.Param('')
+    description = flow.Param("")
     shots = flow.Child(Shots).ui(expanded=True)
 
     def get_default_contextual_edits(self, context_name):
-        if context_name == 'settings':
+        if context_name == "settings":
             default_settings = get_contextual_dict(self._map, context_name)
-            path = default_settings.get('path', 'UNKNOWN_PATH')
+            path = default_settings.get("path", "UNKNOWN_PATH")
 
-            return dict(
-                path=os.path.join(path, self.name()),
-                sequence=self.name()
-            )
+            return dict(path=os.path.join(path, self.name()), sequence=self.name())
 
 
 class ClearSequencesAction(ClearMapAction):
-
     def run(self, button):
         for sequence in self._map.mapped_items():
             for shot in sequence.shots.mapped_items():
@@ -163,9 +152,9 @@ class ClearSequencesAction(ClearMapAction):
 
 class Sequences(ItemMap):
 
-    ICON = ('icons.flow', 'sequence')
+    ICON = ("icons.flow", "sequence")
 
-    item_prefix = 's'
+    item_prefix = "s"
 
     # create_sequence = flow.Child(CreateItemAction)
     clear_sequences = flow.Child(ClearSequencesAction)
@@ -176,14 +165,11 @@ class Sequences(ItemMap):
         return Sequence
 
     def columns(self):
-        return ['Name']
+        return ["Name"]
 
     def _fill_row_cells(self, row, item):
-        row['Name'] = item.name()
+        row["Name"] = item.name()
 
     def get_default_contextual_edits(self, context_name):
-        if context_name == 'settings':
-            return dict(
-                path='PROD',
-                file_category='PROD'
-            )
\ No newline at end of file
+        if context_name == "settings":
+            return dict(path="PROD", file_category="PROD")
